aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Module.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2005-01-30 00:09:23 +0000
committerChris Lattner <sabre@nondot.org>2005-01-30 00:09:23 +0000
commitbca81448ac8e19c588c9a4ad16fc70732b76327c (patch)
treeeb4d515aa88a94cc20e36908ff4336a032129399 /include/llvm/Module.h
parent5c3fa1ec79b3e37e364641a995e08e0ddd933372 (diff)
downloadexternal_llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.zip
external_llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.gz
external_llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.bz2
Improve conformance with the Misha spelling benchmark suite
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@19930 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Module.h')
-rw-r--r--include/llvm/Module.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/llvm/Module.h b/include/llvm/Module.h
index c53ee4e..61ba60f 100644
--- a/include/llvm/Module.h
+++ b/include/llvm/Module.h
@@ -32,16 +32,16 @@ class SymbolTable;
template<> struct ilist_traits<Function>
: public SymbolTableListTraits<Function, Module, Module> {
- // createSentinal is used to create a node that marks the end of the list.
- static Function *createSentinal();
- static void destroySentinal(Function *F) { delete F; }
+ // createSentinel is used to create a node that marks the end of the list.
+ static Function *createSentinel();
+ static void destroySentinel(Function *F) { delete F; }
static iplist<Function> &getList(Module *M);
};
template<> struct ilist_traits<GlobalVariable>
: public SymbolTableListTraits<GlobalVariable, Module, Module> {
- // createSentinal is used to create a node that marks the end of the list.
- static GlobalVariable *createSentinal();
- static void destroySentinal(GlobalVariable *GV) { delete GV; }
+ // createSentinel is used to create a node that marks the end of the list.
+ static GlobalVariable *createSentinel();
+ static void destroySentinel(GlobalVariable *GV) { delete GV; }
static iplist<GlobalVariable> &getList(Module *M);
};